Learn R Programming

ClusTCR2 (version 1.7.3.01)

Motif_from_cluster_file: Code for plotting the Motif based on a specific CDR3 length and V gene (see netplot_ClusTCR2 for details).

Description

Code for plotting the Motif based on a specific CDR3 length and V gene (see netplot_ClusTCR2 for details).

Usage

Motif_from_cluster_file(
  ClusTCR,
  Clust_selected = NULL,
  selected_cluster_column = "Clust_size_order"
)

Value

A ggplot object representing the motif.

Arguments

ClusTCR

Cluster file produced from mcl_cluster.

Clust_selected

Select which cluster to review.

selected_cluster_column

Select the column "Clust_size_order" of the cluster ordered.