Copied code from ggnet's ggnet2 function
ggnet2(
net,
mode = "fruchtermanreingold",
layout.par = NULL,
layout.exp = 0,
alpha = 1,
color = "grey75",
shape = 19,
size = 9,
max_size = 9,
na.rm = NA,
palette = NULL,
alpha.palette = NULL,
alpha.legend = NA,
color.palette = palette,
color.legend = NA,
shape.palette = NULL,
shape.legend = NA,
size.palette = NULL,
size.legend = NA,
size.zero = FALSE,
size.cut = FALSE,
size.min = NA,
size.max = NA,
label = FALSE,
label.alpha = 1,
label.color = "black",
label.size = max_size/2,
label.trim = FALSE,
node.alpha = alpha,
node.color = color,
node.label = label,
node.shape = shape,
node.size = size,
edge.alpha = 1,
edge.color = "grey50",
edge.lty = "solid",
edge.size = 0.25,
edge.label = NULL,
edge.label.alpha = 1,
edge.label.color = label.color,
edge.label.fill = "white",
edge.label.size = max_size/2,
arrow.size = 0,
arrow.gap = 0,
arrow.type = "closed",
legend.size = 9,
legend.position = "right",
...
)A ggplot object displaying the network plot.
net plot from step 2.
= "fruchtermanreingold"
= NULL,
= 0
= 1
= "grey75"
= 19
= 9
= 9
= NA
= NULL
= NULL
= NA
= palette
= NA
= NULL
= NA
= NULL
= NA
= FALSE
= FALSE
= NA
= NA
= FALSE
= 1
= "black"
= max_size/2
= FALSE
see alpha
see color
see label
see shape
see size
= 1
the color of the edges, as a color value, a vector of color
values, or as an edge attribute containing color values.
Defaults to "grey50".
= "solid"
= 0.25
= NULL
= 1
= label.color
= "white"
= max_size/2
= 0
= 0
= "closed"
= 9
= "right"
Other functions in ggplot2