Learn R Programming

ClusTCR2 (version 1.7.3.01)

mcl_cluster_large: Create the files for labeling the linked clusters from ClusTCR_list_to_matrix function

Description

Create the files for labeling the linked clusters from ClusTCR_list_to_matrix function

Usage

mcl_cluster_large(my_file, max.iter = 10, inflation = 1, expansion = 1)

Value

A list containing two elements:

  • 'Cluster_lab': Data frame containing information about the clusters

  • 'Normalised_tabel': Normalized table used in the clustering process

Arguments

my_file

Matrix file produce from ClusTCR

max.iter

Number of iterations to find the steady state of MCL.

inflation

numeric value

expansion

numeric value