Create the files for labeling the linked clusters from ClusTCR_list_to_matrix function
mcl_cluster_large(my_file, max.iter = 10, inflation = 1, expansion = 1)A list containing two elements:
'Cluster_lab': Data frame containing information about the clusters
'Normalised_tabel': Normalized table used in the clustering process
Matrix file produce from ClusTCR
Number of iterations to find the steady state of MCL.
numeric value
numeric value